@@ -69,7 +69,7 @@ class UserRoom_AS_User_Handler:
         self._userRoom_api.connect()
         
     def disconnect(self):
-        self._user_target_room_api.disconnect()
+        self._userRoom_api.disconnect()
             
     def get_username(self):
         return self._username
