@@ -65,6 +65,45 @@ class HIA_Client:
         # insert data into the stream queue for that stream_id   
         self._streams_dict[stream_id].put(data, timeout = 1)      
 
+    def send_data_direct(self,data_packet,stream_id,timestamp=None, send_without_timestamp = False):
+        '''
+        data packet is type list of multichannel samples, each miltichannel sample is also type list 
+        optionally accepts timestamp - must be list with same length as data_packet
+        '''
+        if self._connection_status:
+            data_to_send = []
+            # print(data_packet)
+            # print(f"received data to transmit type {type(data_packet)}, length {len(data_packet)}")
+            if send_without_timestamp:
+                data_to_send = data_packet
+            elif timestamp is None:       
+                t = time.time() - 10000000
+                for sample in data_packet:
+                    x = sample.copy()
+                    x.append(t)
+                    data_to_send.append(x)       
+            else:
+                for index, sample in enumerate(data_packet):
+                    x = sample.copy()
+                    x.append(timestamp[index])
+                    data_to_send.append(x)
+            # print(f"transmitting data type {type(data_to_send)}, length {len(data_to_send)}")
+                    
+            TX_buffer = {"sample": data_to_send}
+
+            packet_payload = {"stream_id": stream_id, "device_type": self._device_type, "hia_id": self._hia_id, "data": json.dumps(TX_buffer)}                
+            packet_payload["experiment"] = {
+                            "packet_labels": self._current_experiment_labels,
+                            "onetime_labels": self._current_experiment_onetime_labels
+                        } 
+            print(len(str(json.dumps(TX_buffer))))
+            
+            self._sio.emit(self._packet_endpoint, packet_payload)      
+        
+        else:
+            message = "{} Socket disconnected, stopping user_data upstream for stream_id: {}".format(self._contex, stream_id)
+            print(message)
+            return
         
     def send_user_data_to_websocket(self, stream_id):  
         packet_ready = False
